$set 3 #Configmenu

$ #ConfigOptions
# Config Options
$ #FocusModel
# Focus Model
$ #WindowPlacement
# Window Placement
$ #ImageDithering
# Image Dithering
$ #OpaqueMove
# Opaque Window Moving
$ #FullMax
# Full Maximization
$ #FocusNew
# Focus New Windows
$ #FocusLast
# Focus Window on Workspace Change
$ #ClickToFocus
# Click to Focus
$ #SloppyFocus
# Sloppy Focus
$ #AutoRaise
# Auto Raise
$ #SmartRows
# Smart Placement (Rows)
$ #SmartCols
# Smart Placement (Columns)
$ #Cascade
# Cascade Placement
$ #LeftRight
# Left to Right
$ #RightLeft
# Right to Left
$ #TopBottom
# Top to Bottom
$ #BottomTop
# Bottom to Top
$ #Tabs
# Use Tabs
$ #Icons
# Use Icons
$ #TabPlacement
# Tab Placement
$ #TabRotateVertical
# Rotate Vertical Tabs
$ #SemiSloppyFocus
# Semi Sloppy Focus
$ #MaxOverSlit
# Maximize Over Slit
$ #SloppyWindowGrouping
# Sloppy Window Grouping
$ #WorkspaceWarping
# Workspace Warping
$ #DesktopWheeling
# Desktop Wheeling
$ #AntiAlias
# AntiAlias
$ #DecorateTransient
# Decorate Transient
